==> 0.0.14.zip: west-sound-hall/src/app/rental/page.tsx <==
import { type Metadata } from 'next'
import Image from 'next/image'
import Link from 'next/link'
import clsx from 'clsx'

import { Container } from '@/components/Container'
import exteriorFront from '@/images/photos/exterior-front.png'
import { EnvelopeIcon, PencilSquareIcon, QuestionMarkCircleIcon } from '@heroicons/react/24/solid'

function SocialLink({
  className,
  href,
  children,
  icon: Icon,
}: {
  className?: string
  href: string
  icon: React.ComponentType<{ className?: string }>
  children: React.ReactNode
}) {
  return (
    <li className={clsx(className, 'flex')}>
      <Link
        href={href}
        className="group flex text-sm font-medium text-zinc-800 transition hover:text-teal-500 dark:text-zinc-200 dark:hover:text-teal-500"
      >
        <Icon className="h-6 w-6 flex-none fill-zinc-500 transition group-hover:fill-teal-500" />
        <span className="ml-4">{children}</span>
      </Link>
    </li>
  )
}

export const metadata: Metadata = {
  title: 'West Sound Hall Rental',
  description:
    'Rental information for the West Sound Hall.',
}

export default function Rental() {
  return (
    <Container className="mt-16 sm:mt-32">
      <div className="grid grid-cols-1 gap-y-16 lg:grid-cols-2 lg:grid-rows-[auto_1fr] lg:gap-y-12">
        <div className="lg:pl-20">
          <div className="max-w-xs px-2.5 lg:max-w-none">
            <Image
              src={exteriorFront}
              alt=""
              sizes="(min-width: 1024px) 32rem, 20rem"
              className="aspect-square rounded-2xl bg-zinc-100 object-cover dark:bg-zinc-800"
            />
          </div>
        </div>
        <div className="lg:order-first lg:row-span-2">
          <h1 className="text-4xl font-bold tracking-tight text-zinc-800 dark:text-zinc-100 sm:text-5xl">
            Hall Rental
          </h1>
          <div className="mt-6 space-y-7 text-base text-zinc-600 dark:text-zinc-400">
            <p>
              The West Sound Community Hall is a public assembly hall, which has
              been in continuous operation since it was built in 1902. In 1999,
              the Hall was listed on the Washington Heritage Register. The West
              Sound Community Club, as steward of the Hall, makes the Hall
              available for nonprofit purposes. Rental fees, shown below, are used
              to pay Hall operating and maintenance expenses.
            </p>
            <p>
              Rental and deposit fees must be paid prior to obtaining access for
              set-up. Rental fees include use of the meeting room, projector
              and stage, chairs and tables, kitchen, rest rooms, water, and
              lights. It does not include trash removal. Cleanup of the Hall
              including removal of trash from the property the same day as the
              event are the responsibilities of the renter.
            </p>
            <p>
              Damage and cleanup deposits, paid in advance, are refundable upon
              satisfactory inspection of the Hall after the event. If there is
              damage to the Hall or cleaning is necessary, deductions will be
              made at the discretion of the Board.
            </p>
          </div>
        </div>
        <div className="order-last sm:order-none lg:pl-20">
          <ul role="list">
            <SocialLink href="/WSCC-Hall-Rental-Application.pdf" icon={PencilSquareIcon}>
              Rental Application Form
            </SocialLink>
            <SocialLink href='/WSCC-Hall-Rental-QA.pdf' icon={QuestionMarkCircleIcon} className="mt-4">
              Rental Q&A
            </SocialLink>
            <SocialLink
              href="mailto:contact@westsoundhall.org"
              icon={EnvelopeIcon}
              className="mt-8 border-t border-zinc-100 pt-8 dark:border-zinc-700/40"
            >
              contact@westsoundhall.org
            </SocialLink>
          </ul>
        </div>
        <div className="lg:col-span-2">
          <h2 className="text-2xl font-bold tracking-tight text-zinc-800 dark:text-zinc-100 sm:text-2xl">
            Rental Rates
          </h2>

          <div className="overflow-x-auto -mx-4 sm:-mx-0">
            <div className="inline-block min-w-full py-2 align-middle">
              <table className="min-w-full divide-y divide-gray-300">
                <thead>
                  <tr>
                    <th scope="col" className="py-3.5 pl-4 pr-3 text-left text-sm font-semibold text-gray-900 sm:pl-0"></th>
                    <th scope="col" className="px-3 py-3.5 text-left text-sm font-semibold text-gray-900">Half day (4 hr)</th>
                    <th scope="col" className="px-3 py-3.5 text-left text-sm font-semibold text-gray-900">All day</th>
                    <th scope="col" className="px-3 py-3.5 text-left text-sm font-semibold text-gray-900">Deposit</th>
                  </tr>
                </thead>
                <tbody className="divide-y divide-gray-200">
                  <tr>
                    <td className="whitespace-nowrap py-4 pl-4 pr-3 text-sm font-medium text-gray-900 sm:pl-0">Orcas non-profit organizations</td>
                    <td className="whitespace-nowrap px-3 py-4 text-sm text-gray-500">$50 or 2 hours for $30*</td>
                    <td className="whitespace-nowrap px-3 py-4 text-sm text-gray-500">$100</td>
                    <td className="whitespace-nowrap px-3 py-4 text-sm text-gray-500">None†</td>
                  </tr>
                  <tr>
                    <td className="whitespace-nowrap py-4 pl-4 pr-3 text-sm font-medium text-gray-900 sm:pl-0">WSCC and OIYC Members</td>
                    <td className="whitespace-nowrap px-3 py-4 text-sm text-gray-500">$50 or 2 hours for $30*</td>
                    <td className="whitespace-nowrap px-3 py-4 text-sm text-gray-500">$100</td>
                    <td className="whitespace-nowrap px-3 py-4 text-sm text-gray-500">None†</td>
                  </tr>
                  <tr>
                    <td className="whitespace-nowrap py-4 pl-4 pr-3 text-sm font-medium text-gray-900 sm:pl-0">Off-island non-profit organizations</td>
                    <td className="whitespace-nowrap px-3 py-4 text-sm text-gray-500">$50</td>
                    <td className="whitespace-nowrap px-3 py-4 text-sm text-gray-500">$100</td>
                    <td className="whitespace-nowrap px-3 py-4 text-sm text-gray-500">$300</td>
                  </tr>
                  <tr>
                    <td className="whitespace-nowrap py-4 pl-4 pr-3 text-sm font-medium text-gray-900 sm:pl-0">Individuals and non-public use</td>
                    <td className="whitespace-nowrap px-3 py-4 text-sm text-gray-500">$40 per hour</td>
                    <td className="whitespace-nowrap px-3 py-4 text-sm text-gray-500">$300</td>
                    <td className="whitespace-nowrap px-3 py-4 text-sm text-gray-500">$300</td>
                  </tr>
                  <tr>
                    <td className="whitespace-nowrap py-4 pl-4 pr-3 text-sm font-medium text-gray-900 sm:pl-0">Government sponsored activities</td>
                    <td className="whitespace-nowrap px-3 py-4 text-sm text-gray-500">$50</td>
                    <td className="whitespace-nowrap px-3 py-4 text-sm text-gray-500">$50</td>
                    <td className="whitespace-nowrap px-3 py-4 text-sm text-gray-500">None†</td>
                  </tr>
                </tbody>
              </table>
            </div>
          </div>

          <div className="mt-6 space-y-5 text-base text-zinc-600 dark:text-zinc-400">
            <h2 className="text-2xl font-bold tracking-tight text-zinc-800 dark:text-zinc-100 sm:text-2xl">
              Use Restrictions
            </h2>

            <p>
              The West Sound Community Hall is a non-smoking facility.
            </p>

            <p>
              The West Sound Community Club Board of Directors reserves the right
              to deny use of the West Sound Community Hall to any individual or
              organization without exception.
            </p>

            <p>
              The West Sound Community Hall may not be used for either personal or
              organizational monetary gain or to promote business activities.
              The only exceptions to this restriction are:

              <ol className="list-decimal ml-8 mt-5">
                <li>
                  Use for fund raising activities sponsored by the West Sound
                  Community Club, a nonprofit corporation, for purposes specified in
                  Article II of the Bylaws of the West Sound Community Club.
                </li>
                <li>
                  Use for fund raising activities sponsored by qualified nonprofit
                  organizations with prior approval by the President of the West Sound
                  Community Club. (Such activities must be less than five days in
                  length and more than 50% of the proceeds must be distributed to the
                  sponsoring nonprofit organization.)
                </li>
              </ol>
            </p>

            <p>
              Any individual or organizational nonpublic use of the hall which
              requires payment of a fee by those attending or offers items for
              sale must be approved in advance by the Board of Directors of the
              West Sound Community Club.
            </p>

            <p>
              If liquor is to be served, renter is responsible for obtaining the
              appropriate license from the
              <Link href="https://lcb.wa.gov/"
                target="_blank" className="pl-1 text-blue-600 visited:text-purple-600 hover:underline"
              >
                Washington State Liquor Control Board
              </Link>.
            </p>

            <p>
              Use of the Hall is subject to renter completing a Hall Rental
              Application which includes an agreement to abide by certain rules
              and restrictions.
            </p>

            <p>
              The Hall must be left clean and renter must remove trash from Hall
              property on the day of the event.
            </p>
          </div>

          <div className="mt-6 space-y-5 text-base text-zinc-600 dark:text-zinc-400">
            <h2 className="text-2xl font-bold tracking-tight text-zinc-800 dark:text-zinc-100 sm:text-2xl">
              Capacity
            </h2>

            <p>
              Maximum occupancy of the Hall is restricted to 126 people.
              Maximum table seating is 84 people.
            </p>
          </div>

          <div className="mt-6 space-y-5 text-base text-zinc-600 dark:text-zinc-400">
            <h2 className="text-2xl font-bold tracking-tight text-zinc-800 dark:text-zinc-100 sm:text-2xl">
              Parking
            </h2>

            <p>
              There is limited public parking available along both sides of Deer
              Harbor Road west of the Hall. However, additional parking for Hall
              events may be arranged on the grounds of the Orcas Island Yacht Club
              picnic shelter located east of the Hall. (Yacht Club events have
              priority on the use of this parking area.) When this parking area is
              available, use for most nonpublic events requires a $50 donation to
              the Yacht Club. Use of the Yacht Club parking area for activities
              other than parking, such as catering activities, bonfires and
              picnics is not allowed.
            </p>

            <p>
              Contact the Property Manager for details on parking.
            </p>
          </div>

          <div className="mt-6 space-y-5 text-base text-zinc-600 dark:text-zinc-400">
            <h2 className="text-2xl font-bold tracking-tight text-zinc-800 dark:text-zinc-100 sm:text-2xl">
              Accessibility
            </h2>

            <p>
              The Hall is accessible by wheelchair using a ramp on the west side.
              The bathrooms are not handicap accessible.
            </p>
          </div>
        </div>
      </div>
    </Container>
  )
}

==> 0.0.25.zip: west-sound-hall/src/app/rental/page.tsx <==
import { type Metadata } from 'next'
import Image from 'next/image'
import Link from 'next/link'
import clsx from 'clsx'

import { Container } from '@/components/Container'
import exteriorFront from '@/images/photos/exterior-front.png'
import { EnvelopeIcon, PencilSquareIcon, QuestionMarkCircleIcon } from '@heroicons/react/24/solid'
import React from 'react'
import { TableCell, TableHeading, TableLeftHeading } from '@/components/Table'

function SocialLink({
  className,
  href,
  children,
  icon: Icon,
}: {
  className?: string
  href: string
  icon: React.ComponentType<{ className?: string }>
  children: React.ReactNode
}) {
  return (
    <li className={clsx(className, 'flex')}>
      <Link
        href={href}
        className="group flex text-sm font-medium text-zinc-800 transition hover:text-teal-500"
      >
        <Icon className="h-6 w-6 flex-none fill-zinc-500 transition group-hover:fill-teal-500" />
        <span className="ml-4">{children}</span>
      </Link>
    </li>
  )
}

export const metadata: Metadata = {
  title: 'West Sound Hall Rental',
  description:
    'Rental information for the West Sound Hall.',
}

export default function Rental() {
  return (
    <Container className="mt-16 sm:mt-32">
      <div className="grid grid-cols-1 gap-y-16 lg:grid-cols-2 lg:grid-rows-[auto_1fr] lg:gap-y-12">
        <div className="lg:pl-20">
          <div className="max-w-xs px-2.5 lg:max-w-none">
            <Image
              src={exteriorFront}
              alt=""
              sizes="(min-width: 1024px) 32rem, 20rem"
              className="aspect-square rounded-2xl bg-zinc-100 object-cover"
            />
          </div>
        </div>
        <div className="lg:order-first lg:row-span-2">
          <h1 className="text-4xl font-bold tracking-tight text-zinc-800 sm:text-5xl">
            West Sound Hall Rental
          </h1>
          <div className="mt-6 space-y-7 text-base text-zinc-600">
            <p>
              The West Sound Community Hall is a public assembly hall, which has
              been in continuous operation since it was built in 1902. In 1999,
              the Hall was listed on the Washington Heritage Register. The West
              Sound Community Club, as steward of the Hall, makes the Hall
              available for nonprofit purposes. Rental fees, shown below, are used
              to pay Hall operating and maintenance expenses.
            </p>
            <p>
              Rental and deposit fees must be paid prior to obtaining access for
              set-up. Rental fees include use of the meeting room, projector
              and stage, chairs and tables, kitchen, rest rooms, water, and
              lights. It does not include trash removal. Cleanup of the Hall
              including removal of trash from the property the same day as the
              event are the responsibilities of the renter.
            </p>
            <p>
              Damage and cleanup deposits, paid in advance, are refundable upon
              satisfactory inspection of the Hall after the event. If there is
              damage to the Hall or cleaning is necessary, deductions will be
              made at the discretion of the Board.
            </p>
            <p>
              Please check the
              <Link href="/calendar" className="pl-1 text-blue-600 hover:underline"
              >calendar
              </Link> for availability.
            </p>
          </div>
        </div>
        <div className="order-last sm:order-none lg:pl-20">
          <ul role="list">
            <SocialLink href="/WSCC-Hall-Rental-Application.pdf" icon={PencilSquareIcon}>
              Rental Application Form
            </SocialLink>
            <SocialLink href='/WSCC-Hall-Rental-QA.pdf' icon={QuestionMarkCircleIcon} className="mt-4">
              Rental Q&A
            </SocialLink>
            <SocialLink
              href="mailto:contact@westsoundhall.org"
              icon={EnvelopeIcon}
              className="mt-8 border-t border-zinc-100 pt-8"
            >
              contact@westsoundhall.org
            </SocialLink>
          </ul>
        </div>
        <div className="lg:col-span-2">
          <h2 className="text-2xl font-bold tracking-tight text-zinc-800 sm:text-2xl">
            Rental Rates
          </h2>

          <div className="overflow-x-auto -mx-4 sm:-mx-0">
            <div className="inline-block min-w-full py-2 align-middle">
              <table className="min-w-full divide-y divide-gray-300">
                <thead>
                  <tr>
                    <th scope="col" className="py-3.5 pl-4 pr-3 sm:pl-0"></th>
                    <TableHeading>Half day (4 hr)</TableHeading>
                    <TableHeading>All day</TableHeading>
                    <TableHeading>Deposit</TableHeading>
                  </tr>
                </thead>
                <tbody className="divide-y divide-gray-200 ">
                  <tr>
                    <TableLeftHeading>Orcas non-profit organizations</TableLeftHeading>
                    <TableCell>$50 or 2 hours for $30*</TableCell>
                    <TableCell>$100</TableCell>
                    <TableCell>None†</TableCell>
                  </tr>
                  <tr>
                    <TableLeftHeading>WSCC and OIYC Members</TableLeftHeading>
                    <TableCell>$50 or 2 hours for $30*</TableCell>
                    <TableCell>$100</TableCell>
                    <TableCell>None†</TableCell>
                  </tr>
                  <tr>
                    <TableLeftHeading>Off-island non-profit organizations</TableLeftHeading>
                    <TableCell>$50</TableCell>
                    <TableCell>$100</TableCell>
                    <TableCell>$300</TableCell>
                  </tr>
                  <tr>
                    <TableLeftHeading>Individuals and non-public use</TableLeftHeading>
                    <TableCell>$40 per hour</TableCell>
                    <TableCell>$300</TableCell>
                    <TableCell>$300</TableCell>
                  </tr>
                  <tr>
                    <TableLeftHeading>Government sponsored activities</TableLeftHeading>
                    <TableCell>$50</TableCell>
                    <TableCell>$50</TableCell>
                    <TableCell>None†</TableCell>
                  </tr>
                </tbody>
              </table>
            </div>
          </div>

          <div className="mt-6 space-y-5 text-base text-zinc-600">
            <h2 className="text-2xl font-bold tracking-tight text-zinc-800 sm:text-2xl">
              Use Restrictions
            </h2>

            <p>
              The West Sound Community Hall is a non-smoking facility.
            </p>

            <p>
              The West Sound Community Club Board of Directors reserves the right
              to deny use of the West Sound Community Hall to any individual or
              organization without exception.
            </p>

            <p>
              The West Sound Community Hall may not be used for either personal or
              organizational monetary gain or to promote business activities.
              The only exceptions to this restriction are:
            </p>

            <ol className="list-decimal ml-8 mt-5">
              <li>
                Use for fund raising activities sponsored by the West Sound
                Community Club, a nonprofit corporation, for purposes specified in
                Article II of the Bylaws of the West Sound Community Club.
              </li>
              <li>
                Use for fund raising activities sponsored by qualified nonprofit
                organizations with prior approval by the President of the West Sound
                Community Club. (Such activities must be less than five days in
                length and more than 50% of the proceeds must be distributed to the
                sponsoring nonprofit organization.)
              </li>
            </ol>

            <p>
              Any individual or organizational nonpublic use of the hall which
              requires payment of a fee by those attending or offers items for
              sale must be approved in advance by the Board of Directors of the
              West Sound Community Club.
            </p>

            <p>
              If liquor is to be served, renter is responsible for obtaining the
              appropriate license from the
              <Link href="https://lcb.wa.gov/"
                target="_blank" className="pl-1 text-blue-600 visited:text-purple-600 hover:underline"
              >
                Washington State Liquor Control Board
              </Link>.
            </p>

            <p>
              Use of the Hall is subject to renter completing a Hall Rental
              Application which includes an agreement to abide by certain rules
              and restrictions.
            </p>

            <p>
              The Hall must be left clean and renter must remove trash from Hall
              property on the day of the event.
            </p>
          </div>

          <div className="mt-6 space-y-5 text-base text-zinc-600">
            <h2 className="text-2xl font-bold tracking-tight text-zinc-800 sm:text-2xl">
              Capacity
            </h2>

            <p>
              Maximum occupancy of the Hall is restricted to 126 people.
              Maximum table seating is 84 people.
            </p>
          </div>

          <div className="mt-6 space-y-5 text-base text-zinc-600">
            <h2 className="text-2xl font-bold tracking-tight text-zinc-800 sm:text-2xl">
              Parking
            </h2>

            <p>
              There is limited public parking available along both sides of Deer
              Harbor Road west of the Hall. However, additional parking for Hall
              events may be arranged on the grounds of the Orcas Island Yacht Club
              picnic shelter located east of the Hall. (Yacht Club events have
              priority on the use of this parking area.) When this parking area is
              available, use for most nonpublic events requires a $50 donation to
              the Yacht Club. Use of the Yacht Club parking area for activities
              other than parking, such as catering activities, bonfires and
              picnics is not allowed.
            </p>

            <p>
              Contact the Property Manager for details on parking.
            </p>
          </div>

          <div className="mt-6 space-y-5 text-base text-zinc-600">
            <h2 className="text-2xl font-bold tracking-tight text-zinc-800 sm:text-2xl">
              Accessibility
            </h2>

            <p>
              The Hall is accessible by wheelchair using a ramp on the west side.
              The bathrooms are not handicap accessible.
            </p>
          </div>
        </div>
      </div>
    </Container>
  )
}
